"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.collectUserFlowsCommand = void 0;
const tslib_1 = require("tslib");
const user_flow_1 = require("../../internal/utils/user-flow");
const index_1 = require("../../core/loggin/index");
const interactive_1 = require("../../core/options/interactive");
const dryRun_1 = require("../../core/options/dryRun");
const open_1 = require("./options/open");
const openFileInBrowser = require("open");
const options_1 = require("./options");
const serve_command_1 = require("./serve-command");
const init_1 = require("../init");
exports.collectUserFlowsCommand = {
    command: 'collect',
    description: 'Run a set of user flows and save the result',
    builder: (y) => y.options(options_1.COLLECT_OPTIONS).help(),
    module: {
        handler: (argv) => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
            (0, index_1.logVerbose)(`run "collect" as a yargs command with args:`);
            (0, index_1.logVerbose)(argv);
            // get validation and errors for RC & options configurations
            yield (0, init_1.run)(argv);
            const { url, ufPath, outPath, format, openReport, serveCommand, awaitServeStdout } = argv;
            const r = yield (0, serve_command_1.startServerIfNeeded)(() => {
                return run({ url, ufPath, outPath, format, openReport, serveCommand, awaitServeStdout });
            }, { serveCommand, awaitServeStdout });
        })
    }
};
function run(cfg) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        let { url, ufPath, outPath, format } = cfg;
        // Load and run user-flows in parallel
        const userFlows = (0, user_flow_1.loadFlow)(ufPath);
        yield sequeltial(userFlows.map(({ exports: provider, path }) => (_) => (0, user_flow_1.collectFlow)({ url, dryRun: (0, dryRun_1.get)() }, Object.assign(Object.assign({}, provider), { path }))
            .then((flow) => !(0, dryRun_1.get)() ? (0, user_flow_1.persistFlow)(flow, provider.flowOptions.name, { outPath, format }) : Promise.resolve(['']))
            .then((fileNames) => {
            // open report if requested and not in executed in CI
            if (!(0, dryRun_1.get)() && (0, open_1.get)() && (0, interactive_1.get)()) {
                const file = fileNames.find(i => i.includes('.html'));
                file && openFileInBrowser(file, { wait: false });
            }
            return Promise.resolve();
        })));
    });
}
exports.run = run;
function sequeltial(set) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        let res = undefined;
        for (let i = 0; i < set.length; i++) {
            res = yield set[i](res);
        }
    });
}
//# sourceMappingURL=collect.js.map