"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.initCommand = void 0;
const tslib_1 = require("tslib");
const index_1 = require("../core/loggin/index");
const config_1 = require("../internal/config/config");
const setup_1 = require("../internal/config/setup");
const open_1 = require("./collect/options/open");
const rc_1 = require("../core/options/rc");
exports.initCommand = {
    command: 'init',
    description: 'Setup .user-flowrc.json',
    builder: (y) => y.option(open_1.param),
    module: {
        handler: (argv) => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
            (0, index_1.logVerbose)(`run "init" as a yargs command`);
            const cfg = yield run(argv);
            (0, index_1.log)('user-flow CLI is set up now! 🎉');
            (0, index_1.logVerbose)(cfg);
        })
    }
};
function getCLIConfigFromArgv(argv) {
    const { url, ufPath, serveCommand, awaitServeStdout, outPath, format } = (argv || {});
    const cfg = {
        collect: {
            url,
            ufPath,
            serveCommand,
            awaitServeStdout
        },
        persist: {
            outPath,
            format
        }
    };
    return cfg;
}
function run(argv) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        const cliCfg = getCLIConfigFromArgv(argv);
        //console.log('run init', cliCfg)
        const config = Object.assign(Object.assign({}, cliCfg), (yield (0, setup_1.ensureUrl)(cliCfg)
            .then(setup_1.ensureUfPath)
            .then(setup_1.ensureFormat)
            .then(setup_1.ensureOutPath)
        // defaults should be last as it takes user settings
        ));
        const rcPath = (0, rc_1.get)();
        (0, config_1.updateRepoConfig)(config, rcPath);
        return config;
    });
}
exports.run = run;
//# sourceMappingURL=init.js.map