"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadFlow = exports.collectFlow = exports.persistFlow = void 0;
const tslib_1 = require("tslib");
const fs_1 = require("fs");
// @ts-ignore
const api_1 = require("lighthouse/lighthouse-core/fraggle-rock/api");
const puppeteer = require("puppeteer");
const model_1 = require("../../types/model");
const file_1 = require("./file");
const path_1 = require("path");
const loggin_1 = require("../../core/loggin");
const dryRun_1 = require("../../core/options/dryRun");
const cli_modes_1 = require("../../cli-modes");
const _persistMethod = new Map();
_persistMethod.set('html', ({ outPath, flow, name }) => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
    const report = yield flow.generateReport();
    const fileName = (0, path_1.join)(outPath, `${(0, file_1.toFileName)(name)}.uf.html`);
    (0, file_1.writeFile)(fileName, report);
    return fileName;
}));
_persistMethod.set('json', ({ outPath, flow, name }) => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
    const report = yield flow.createFlowResult();
    const fileName = (0, path_1.join)(outPath, `${(0, file_1.toFileName)(name)}.uf.json`);
    (0, file_1.writeFile)(fileName, JSON.stringify(report));
    return fileName;
}));
function persistFlow(flow, name, { outPath, format }) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        return Promise.all(format.map((f) => _persistMethod.get(f)({ flow, name, outPath })));
    });
}
exports.persistFlow = persistFlow;
function collectFlow(collectOptions, userFlowProvider) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        let { launchOptions, flowOptions, interactions } = userFlowProvider;
        launchOptions = launchOptions || {
            headless: false,
            defaultViewport: { isMobile: true, isLandscape: false, width: 800, height: 600 }
        };
        // @TODO consider CI vs dev mode => headless, open, persist etc
        if ((0, cli_modes_1.detectCliMode)() !== 'DEFAULT') {
            (0, loggin_1.logVerbose)(`Set headless to true as we are running in ${(0, cli_modes_1.detectCliMode)()} mode`);
            launchOptions.headless = true;
        }
        (0, loggin_1.logVerbose)(`Collect: ${flowOptions.name} from URL ${collectOptions.url}`);
        (0, loggin_1.logVerbose)(`File path: ${(0, path_1.normalize)(userFlowProvider.path)}`);
        let start = Date.now();
        // setup ppt, and start flow
        (0, loggin_1.logVerbose)(`launchOptions: ${JSON.stringify(launchOptions)}`);
        const browser = yield puppeteer.launch(launchOptions);
        const page = yield browser.newPage();
        const flow = !(0, dryRun_1.get)() ? yield (0, api_1.startFlow)(page, flowOptions) : new model_1.UserFlowMock(page, flowOptions);
        // run custom interactions
        yield interactions({ flow, page, browser, collectOptions });
        (0, loggin_1.logVerbose)(`Duration: ${flowOptions.name}: ${(Date.now() - start) / 1000}`);
        yield browser.close();
        return flow;
    });
}
exports.collectFlow = collectFlow;
function loadFlow(path) {
    let ufDirectory = [];
    try {
        ufDirectory = (0, fs_1.readdirSync)(path);
    }
    catch (e) {
        throw new Error(`ufPath: ${path} is no directory`);
    }
    const flows = (0, fs_1.readdirSync)(path).map((p) => (0, file_1.resolveAnyFile)((0, path_1.join)(path, p)));
    return flows;
}
exports.loadFlow = loadFlow;
//# sourceMappingURL=user-flow.js.map